package fitconnect.client.crypto;

import com.nimbusds.jose.JOSEException;
import com.nimbusds.jose.jwk.KeyUse;
import com.nimbusds.jose.jwk.RSAKey;
import com.nimbusds.jose.jwk.gen.RSAKeyGenerator;
import fitconnect.client.impl.crypto.FitCoCryptoService;
import org.junit.jupiter.api.Test;

import java.util.UUID;

import static org.junit.jupiter.api.Assertions.*;

class JWECryptoServiceTest {

    final fitconnect.api.crypto.JWECryptoService underTest = new FitCoCryptoService();

    @Test
    void encryptData() throws JOSEException {

        // Given
        final RSAKey privateKey = generateRsaKey(4096);
        final RSAKey publicKey = privateKey.toPublicJWK();

        // When
        String encryptedData = underTest.encryptString(publicKey, "some foo");

        // Then
        assertNotNull(encryptedData);
        assertNotEquals("some foo", encryptedData);
    }

    @Test
    void decryptData() throws JOSEException {

        // Given
        final RSAKey privateKey = generateRsaKey(4096);
        final RSAKey publicKey = privateKey.toPublicJWK();
        String encryptedData = underTest.encryptString(publicKey, "some foo");

        // When
        String decrypted = underTest.decryptString(privateKey, encryptedData);

        // Then
        assertNotNull(decrypted);
        assertEquals("some foo", decrypted);
    }

    public static RSAKey generateRsaKey(int size) throws JOSEException {
        return new RSAKeyGenerator(size)
                .keyUse(KeyUse.ENCRYPTION)
                .keyID(UUID.randomUUID().toString())
                .generate();
    }

}